@@ -9,15 +9,15 @@ from typing import Any, Dict
 
 import pandas as pd
 from mitosheet.pro.download.formatting import add_formatting_to_excel_sheet
-from mitosheet.steps_manager import StepsManager
+from mitosheet.types import StepsManagerType
 from mitosheet.user import is_pro
 
 
-def get_dataframe_as_excel(event: Dict[str, Any], steps_manager: StepsManager) -> str:
+def get_dataframe_as_excel(params: Dict[str, Any], steps_manager: StepsManagerType) -> str:
     """
     Sends a dataframe as a excel string.
     """
-    sheet_indexes = event['sheet_indexes']
+    sheet_indexes = params['sheet_indexes']
     is_pro_user = is_pro()
 
     # We write to a buffer so that we don't have to save the file
@@ -30,7 +30,7 @@ def get_dataframe_as_excel(event: Dict[str, Any], steps_manager: StepsManager) -
             sheet_name = steps_manager.curr_step.df_names[sheet_index]
             df.to_excel(
                 writer, 
-                sheet_name=sheet_name, 
+                sheet_name=sheet_name[:31], # Make sure we don't pass more than 31 characters, it's not a valid sheet name 
                 index=False
             )
 
