@@ -5,7 +5,7 @@
 # Distributed under the terms of the GPL License.
 
 
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple, Union
 
 if TYPE_CHECKING:
     from mitosheet.state import State
@@ -27,13 +27,9 @@ class CodeChunk:
     def __init__(self, 
         prev_state: State,
         post_state: State,
-        params: Dict[str, Any], 
-        execution_data: Optional[Dict[str, Any]]
     ):
         self.prev_state = prev_state
         self.post_state = post_state
-        self.params = params
-        self.execution_data = execution_data
 
     def __repr__(self) -> str:
         return self.__class__.__name__
@@ -46,7 +42,7 @@ class CodeChunk:
         """Returns a detailed comment explaing what happened in this CodeChunk"""
         raise NotImplementedError('Implement in subclass')
 
-    def get_code(self) -> List[str]:
+    def get_code(self) -> Tuple[List[str], List[str]]:
         """Returns a the list of code strings that this code chunk executes"""
         raise NotImplementedError('Implement in subclass')
 
@@ -54,22 +50,6 @@ class CodeChunk:
     # data that you're allowed to reference, and then check this when you create
     # the step, for strong typing!
 
-    def get_param(self, key: str) -> Any:
-        """
-        Gets a value from the params passed to this CodeChunk
-        """
-        if key in self.params:
-            return self.params[key]
-        return None
-
-    def get_execution_data(self, key: str) -> Any:
-        """
-        Gets a value from the execution_data passed to this CodeChunk
-        """
-        if self.execution_data and key in self.execution_data:
-            return self.execution_data[key]
-        return None
-
     def params_match(self, other_code_chunk: "CodeChunk", param_keys: List[str]) -> bool:
         """
         Given a different code chunk, and a list of keys to check, returns True if
@@ -77,7 +57,7 @@ class CodeChunk:
         CodeChunks are compatible for combination.
         """
         for key in param_keys:
-            if self.get_param(key) != other_code_chunk.get_param(key):
+            if self.__dict__[key] != other_code_chunk.__dict__[key]:
                 return False
         return True
 
