@@ -5,48 +5,48 @@
 # Distributed under the terms of the GPL License.
 
 
-from typing import List, Optional
+from typing import Any, Dict, List, Optional, Tuple
 
 from mitosheet.code_chunks.code_chunk import CodeChunk
 from mitosheet.code_chunks.code_chunk_utils import get_right_combine_with_column_delete_code_chunk
 from mitosheet.code_chunks.step_performers.column_steps.delete_column_code_chunk import DeleteColumnsCodeChunk
 from mitosheet.parser import parse_formula
+from mitosheet.state import State
+from mitosheet.types import ColumnID
 
 
 class SetColumnFormulaCodeChunk(CodeChunk):
 
+    def __init__(self, prev_state: State, post_state: State, sheet_index: int, column_id: ColumnID, new_formula: str):
+        super().__init__(prev_state, post_state)
+        self.sheet_index = sheet_index
+        self.column_id = column_id
+        self.new_formula = new_formula
+
+        self.df_name = self.post_state.df_names[self.sheet_index]
+
     def get_display_name(self) -> str:
         return 'Updated column formula'
     
     def get_description_comment(self) -> str:
-        sheet_index = self.get_param('sheet_index')
-        column_id = self.get_param('column_id')
-        column_header = self.post_state.column_ids.get_column_header_by_id(sheet_index, column_id)
+        column_header = self.post_state.column_ids.get_column_header_by_id(self.sheet_index, self.column_id)
         return f'Set formula of {column_header}'
 
-    def get_code(self) -> List[str]:
-        """
-        Use this helper function when making a change to a column and you want to transpile
-        the columns that are dependant on the column you changed. 
-        """
-        sheet_index = self.get_param('sheet_index')
-        column_id = self.get_param('column_id')
-        new_formula = self.get_param('new_formula')
-
-        column_header = self.post_state.column_ids.get_column_header_by_id(sheet_index, column_id)
+    def get_code(self) -> Tuple[List[str], List[str]]:
+        column_header = self.post_state.column_ids.get_column_header_by_id(self.sheet_index, self.column_id)
         python_code, _, _ = parse_formula(
-            new_formula, 
+            self.new_formula, 
             column_header,
-            self.post_state.column_ids.get_column_headers(sheet_index),
-            df_name=self.post_state.df_names[sheet_index]
+            self.post_state.column_ids.get_column_headers(self.sheet_index),
+            df_name=self.post_state.df_names[self.sheet_index]
         )
 
         return [
             python_code
-        ]
+        ], []
 
     def get_edited_sheet_indexes(self) -> List[int]:
-        return [self.get_param('sheet_index')]
+        return [self.sheet_index]
 
     def _combine_right_with_delete_column_code_chunk(self, other_code_chunk: DeleteColumnsCodeChunk) -> Optional[CodeChunk]:
         return get_right_combine_with_column_delete_code_chunk(
