@@ -1,38 +1,23 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Mito.
-# Distributed under the terms of the Modified BSD License.
-
+# Copyright (c) Saga Inc.
+# Distributed under the terms of the GPL License.
 """
 Utilities to help with type functions
 """
 
-from typing import Any, List, Optional, Set, Tuple, Union
+from typing import Any, List, Optional, Tuple, Union
 import pandas as pd
 import numpy as np
 
 from mitosheet.sheet_functions.sheet_function_utils import is_series_of_constant
 
-# Because type(1) = int, thus 1 is a 'number' in the Mito type system
-MITO_PRIMITIVE_TYPE_MAPPING = {
-    'boolean': [bool],
-    'timestamp': [pd.Timestamp],
-    'timedelta': [pd.Timedelta],
-    'number': [int, float],
-    'string': [str],
-}
-
-BOOLEAN_SERIES = 'boolean_series'
-DATETIME_SERIES = 'datetime_series'
-TIMEDELTA_SERIES = 'timedelta_series'
-NUMBER_SERIES = 'number_series'
-STRING_SERIES = 'string_series'
-
 # A series of helper functions that help you figure
 # out which dtype we're dealing with. NOTE: since some
 # of these types can be different varieties (e.g. int can be int64, uint64)
 # we try to check for them with simple expressions
+# NOTE: these should be identical to the TS utilities in dtypes.tsx
 
 def is_bool_dtype(dtype: str) -> bool:
     return 'bool' == dtype
@@ -54,6 +39,9 @@ def is_datetime_dtype(dtype: str) -> bool:
 def is_timedelta_dtype(dtype: str) -> bool:
     return 'timedelta' in dtype
 
+def is_number_dtype(dtype: str) -> bool:
+    return is_int_dtype(dtype) or is_float_dtype(dtype)
+
 def is_none_type(value: Union[str, None]) -> bool:
     """
     Helper function for determining if a value should be treated as None
@@ -75,37 +63,6 @@ def get_float_dt_td_columns(df: pd.DataFrame) -> Tuple[List[Any], List[Any], Lis
 
     return float_columns, date_columns, timedelta_columns
 
-def get_mito_type(obj: Any) -> str:
-
-    if isinstance(obj, pd.Series):
-        dtype = str(obj.dtype)
-        if is_bool_dtype(dtype):
-            return BOOLEAN_SERIES
-        elif is_int_dtype(dtype) or is_float_dtype(dtype):
-            return NUMBER_SERIES
-        elif is_string_dtype(dtype):
-            return STRING_SERIES
-        elif is_datetime_dtype(dtype):
-            return DATETIME_SERIES
-        elif is_timedelta_dtype(dtype):
-            return TIMEDELTA_SERIES
-        else:
-            # We default to string, when not sure what else
-            return STRING_SERIES
-
-    elif isinstance(obj, pd.Timestamp):
-        return 'timestamp'
-    elif isinstance(obj, pd.Timedelta):
-        return 'timedelta'
-    else:
-        obj_type = type(obj)
-
-        for key, value in MITO_PRIMITIVE_TYPE_MAPPING.items():
-            if obj_type in value:
-                return key
-
-    return STRING_SERIES
-
 
 def get_nan_indexes_metadata(*argv: pd.Series) -> Tuple[pd.Index, pd.Index]: 
     """
@@ -151,29 +108,56 @@ def put_nan_indexes_back(series: pd.Series, original_index: pd.Index) -> pd.Seri
 
 def get_datetime_format(string_series: pd.Series) -> Optional[str]:
     """
-    Given a series of datetime strings, detects if the format is MM-DD-YYYY,
-    which is the most common format that pandas does not default to.
-
-    In the future, we can extend this to detect other formats. Returns None
-    if infer_datetime_format is good enough!
+    Given a series of datetime strings, guesses the most likely date format.
     """
     try:
-        # If we can convert all non null inputs, then we assume that pandas
-        # is guessing the input correctly
+        # Import log function here to avoid circular import
+        from mitosheet.telemetry.telemetry_utils import log
+
+        # If we can convert all non null inputs, then we assume we guessed correctly
         non_null_inputs = string_series[~string_series.isna()]
+
+        # First try letting pandas guess the correct datetime
         converted = pd.to_datetime(non_null_inputs, errors='coerce', infer_datetime_format=True)
-        if converted.isna().sum() > 0:
-            raise Exception("Non full conversion")
+        if converted.isna().sum() == 0:
+            return None
+
+        # TODO: Add the most popular formats to here and check them first before 
+        # trying all of the formats below for performance.
+
+        # Then we try a bunch of other formats it could be
+        sample_string_datetime = string_series[string_series.first_valid_index()]
+        FORMATS = [
+            '%m{s}%d{s}%Y', 
+            '%d{s}%m{s}%Y', 
+            '%Y{s}%d{s}%m', 
+            '%Y{s}%m{s}%d', 
+            '%m{s}%d{s}%Y %H:%M:%S', 
+            '%d{s}%m{s}%Y  %H:%M:%S', 
+            '%Y{s}%d{s}%m  %H:%M:%S', 
+            '%Y{s}%m{s}%d  %H:%M:%S'
+        ]
+        SEPERATORS = ['/', '-', '.', ',', ':', ' ', '']
+
+        for seperator in SEPERATORS:
+            if seperator in sample_string_datetime:
+                for _format in FORMATS:
+                    format = _format.format(s=seperator)
+                    if test_datetime_format(non_null_inputs, format):
+                        return format  
+
+        log('unable_to_determine_datetime_format_on_cast')
         return None
     except:
-        # Otherwise, we manually figure out the format.
-        sample_string_datetime = string_series[string_series.first_valid_index()]
-        if "/" in sample_string_datetime: 
-            return '%m/%d/%Y'
-        else:
-            return '%m-%d-%Y'
+        log('unable_to_determine_datetime_format_on_cast')
+        return None
 
 
+def test_datetime_format(series: pd.Series, _format: str) -> bool:
+    converted = pd.to_datetime(series, errors='coerce', format=_format)
+    return converted.isna().sum() == 0
+        
+
 def get_million_identifier_in_string(string: str) -> Union[str, None]:
     """
     Given a string, returns the million identifier in it. 
@@ -204,4 +188,4 @@ def get_billion_identifier_in_string(string: str) -> Union[str, None]:
         if identifier in string:
             return identifier
 
-    return None
+    return None
\ No newline at end of file
