@@ -42,6 +42,8 @@ from mitosheet.step_performers.melt import MeltStepPerformer
 from mitosheet.enterprise.step_performers.one_hot_encoding import OneHotEncodingStepPerformer
 from mitosheet.pro.step_performers.set_dataframe_format import SetDataframeFormatStepPerformer
 from mitosheet.step_performers.import_steps.dataframe_import import DataframeImportStepPerformer
+from mitosheet.step_performers.import_steps.snowflake_import import SnowflakeImportStepPerformer
+from mitosheet.step_performers.import_steps.excel_range_import import ExcelRangeImportStepPerformer
 # AUTOGENERATED LINE: IMPORT (DO NOT DELETE)
 
 # All steps must be listed in this variable. Note the Type annotation allows for
@@ -79,6 +81,8 @@ STEP_PERFORMERS: List[Type[StepPerformer]] = [
     OneHotEncodingStepPerformer,
     SetDataframeFormatStepPerformer,
     DataframeImportStepPerformer,
+    SnowflakeImportStepPerformer,
+    ExcelRangeImportStepPerformer,
     # AUTOGENERATED LINE: EXPORT (DO NOT DELETE)
 ]
 
