@@ -62,7 +62,12 @@ class DeleteColumnStepPerformer(StepPerformer):
         execution_data: Optional[Dict[str, Any]],
     ) -> List[CodeChunk]:
         return [
-            DeleteColumnsCodeChunk(prev_state, post_state, params, execution_data)
+            DeleteColumnsCodeChunk(
+                prev_state, 
+                post_state, 
+                get_param(params, 'sheet_index'), 
+                get_param(params, 'column_ids'), 
+            )
         ]
 
     @classmethod
