@@ -43,7 +43,7 @@ class DataframeDeleteStepPerformer(StepPerformer):
         post_state.column_ids.remove_df(sheet_index)
         post_state.column_spreadsheet_code.pop(sheet_index)
         post_state.column_filters.pop(sheet_index)
-        post_state.column_format_types.pop(sheet_index)
+        post_state.df_formats.pop(sheet_index)
         post_state.dfs.pop(sheet_index)
         post_state.df_names.pop(sheet_index)
         post_state.df_sources.pop(sheet_index)
@@ -64,13 +64,8 @@ class DataframeDeleteStepPerformer(StepPerformer):
             DataframeDeleteCodeChunk(
                 prev_state, 
                 post_state, 
-                # Our dataframe delete code chunk can support mulitple dataframes being deleted
-                # at once, so we turn it into this format
-                {
-                    'sheet_indexes': [params['sheet_index']],
-                    'old_dataframe_names': [params['old_dataframe_name']],
-                }, 
-                execution_data
+                [params['sheet_index']],
+                [params['old_dataframe_name']]
             )
         ]
     
