@@ -142,7 +142,14 @@ class FilterStepPerformer(StepPerformer):
         from mitosheet.code_chunks.step_performers.filter_code_chunk import \
             FilterCodeChunk
         return [
-            FilterCodeChunk(prev_state, post_state, params, execution_data)
+            FilterCodeChunk(
+                prev_state, 
+                post_state, 
+                get_param(params, 'sheet_index'),
+                get_param(params, 'column_id'),
+                get_param(params, 'operator'),
+                get_param(params, 'filters'),
+            )
         ]
 
     @classmethod
