@@ -86,6 +86,7 @@ class GraphStepPerformer(StepPerformer):
         graph_creation: Dict[str, Any] = get_param(params, 'graph_creation')
         graph_styling: Dict[str, Any] = get_param(params, 'graph_styling')
         graph_rendering: Dict[str, Any] = get_param(params, 'graph_rendering')
+        include_plotlyjs: bool = get_param(params, 'include_plotlyjs')
 
         # We make a new state to modify it
         post_state = prev_state.copy()
@@ -176,7 +177,7 @@ class GraphStepPerformer(StepPerformer):
                 )
             )
 
-            html_and_script = get_html_and_script_from_figure(fig, height, width)
+            html_and_script = get_html_and_script_from_figure(fig, height, width, include_plotlyjs)
 
             graph_generation_code = get_plotly_express_graph_code(
                 graph_type,
@@ -231,11 +232,8 @@ class GraphStepPerformer(StepPerformer):
             EmptyCodeChunk(
                 prev_state, 
                 post_state, 
-                {
-                    'display_name': 'Edited graph',
-                    'description_comment': 'Edited a graph',
-                },
-                execution_data
+                'Edited graph',
+                'Edited a graph',
             )
         ]
 
