@@ -5,6 +5,7 @@
 # Distributed under the terms of the GPL License.
 
 from typing import Dict, List, Optional, Any, Union
+from mitosheet.state import State
 import io
 from xmlrpc.client import boolean
 from mitosheet.transpiler.transpile_utils import column_header_to_transpiled_code
@@ -38,87 +39,6 @@ GRAPH_TITLE_LABELS = {
     DENSITY_CONTOUR: "density contour",
 }
 
-# TAB is used in place of \t in generated code because
-# Jupyter turns \t into a grey arrow, but converts four spaces into a tab.
-TAB = "    "
-
-
-def get_barmode(graph_type: str) -> Optional[str]:
-    """
-    Helper function for determing the barmode to apply to the graph creation function, depending
-    on the type of graph being created
-    """
-    if graph_type == BOX:
-        return "stack"
-    elif graph_type == HISTOGRAM:
-        return "group"
-    elif graph_type == BAR:
-        return "group"
-    else:
-        return None
-
-
-def param_dict_to_code(param_dict: Dict[str, Any], level: int=0, as_single_line: boolean=False) -> str:
-    """
-    Takes a potentially nested params dictonary and turns it into a
-    code string that we can use in the graph generated code.
-
-    level should be 0 if we are at the highest level dict, and otherwise
-    should increment by 1 anytime we enter a new subdictonary.
-    """
-
-    # Make sure we handle as a single line properly
-    if as_single_line:
-        TAB_CONSTANT = ''
-        NEWLINE_CONSTANT = ''
-    else:
-        TAB_CONSTANT = TAB
-        NEWLINE_CONSTANT = '\n'
-
-    if level == 0:
-        code = f"{NEWLINE_CONSTANT}"
-    else:
-        code = f"dict({NEWLINE_CONSTANT}"
-
-    value_num = 0
-    for key, value in param_dict.items():
-        if isinstance(value, dict):
-            # Recurse on this nested param dictonary
-            code_chunk = f"{key} = {param_dict_to_code(value, level=level + 1)}"
-        else:
-            # We use this slighly misnamed function to make sure values get transpiled right
-            code_chunk = f"{key}={column_header_to_transpiled_code(value)}"
-        
-        # If we're not on the first value in this dict, we need to add a 
-        # command new line after the last value
-        if value_num != 0:
-            code += f", {NEWLINE_CONSTANT}"
-
-        value_num += 1
-
-        # Add spacing before the param
-        code += f"{TAB_CONSTANT * (level + 1)}"
-
-        code += f"{code_chunk}"
-
-    if level == 0:
-        code += f"{NEWLINE_CONSTANT}"
-    else:
-        # Make sure to close the dict
-        code += f"{NEWLINE_CONSTANT}{TAB_CONSTANT * (level)})"
-    
-    return code
-
-
-def create_parameter(param_key: str, param_value: Optional[str], format_as_string: bool) -> str:
-    """
-    Returns the params ready to be used in the transpiled code.
-    """
-    if format_as_string:
-        return f"{param_key}='{param_value}'"
-    else:
-        return f"{param_key}={param_value}"
-
 
 def get_graph_title(
     x_axis_column_headers: List[ColumnHeader],
@@ -170,7 +90,8 @@ def get_new_graph_tab_name(graph_data_dict: Dict[str, Dict[str, Any]]) -> str:
 
 
 def get_html_and_script_from_figure(
-    fig: go.Figure, height: int, width: int
+    fig: go.Figure, height: int, width: int,
+    include_plotlyjs: boolean,
 ) -> Dict[str, str]:
     """
     Given a plotly figure, generates HTML from it, and returns
@@ -188,23 +109,44 @@ def get_html_and_script_from_figure(
     fig.write_html(
         buffer,
         full_html=False,
-        include_plotlyjs=False,
+        include_plotlyjs=include_plotlyjs,
         default_height=height,
         default_width=width,
     )
 
     original_html = buffer.getvalue()
-    # First, we remove the main div, and the resulting whitespace, to just have the children
-    original_html = original_html[5:]
-    original_html = original_html[:-6]
-    original_html = original_html.strip()
 
-    # Then, we split the children into the div, and the script
-    # making sure to remove the script tag (so we can execute it)
-    script_start = '<script type="text/javascript">'
-    script_end = "</script>"
-    split_html = original_html.split(script_start)
-    div = split_html[0]
-    script = split_html[1][: -len(script_end)]
+    # Everything in a script tag we want to treat as one big script
+
+    # The get the graph div, which looks like: <div id="9c21d143-3fcd-4958-9295-ac7ada668186" class="plotly-graph-div" style="height:425px; width:970px;"></div>
+    # This is the only div we need to put on the frontend.
+    div = original_html[original_html.find('<div id='):original_html.find('</div>', original_html.find('<div id='))]
+
+    # Get all the scripts that are between the <script> tags, and join them together. If include_plotlyjs is true, this includes
+    # the plotly js script, and otherwise, it's just the data and the script that uses Plotly to build the graph on the div above
+    script = ''
+    index = 0
+    while index < len(original_html):
+        script_start = original_html.find('<script type="text/javascript">', index)
+        script_end = original_html.find('</script>', script_start)
+
+        if script_start == -1 or script_end == -1:
+            break
+
+        # Get rid of the initial script
+        script_start += len('<script type="text/javascript">')
+        script = script + original_html[script_start:script_end] + ';\n'
+        index = script_end + 9
 
     return {"html": div, "script": script}
+
+def get_column_header_from_optional_column_id_graph_param(
+    state: State, 
+    graph_creation_params: Dict[str, Any], 
+    param_name: str
+) -> Optional[ColumnHeader]:
+    sheet_index = graph_creation_params['sheet_index']
+    if param_name in graph_creation_params.keys() and graph_creation_params[param_name] in state.column_ids.column_id_to_column_header[sheet_index].keys():
+        return state.column_ids.get_column_header_by_id(sheet_index, graph_creation_params[param_name])
+    else: return None
+
