@@ -14,7 +14,7 @@ import platform
 import sys
 import time
 from copy import copy
-from typing import Any, Dict
+from typing import Any, Dict, Optional
 
 from mitosheet.errors import MitoError, get_recent_traceback_as_list
 from mitosheet.telemetry.anonymization_utils import anonymize_object, get_final_private_params_for_single_kv
@@ -69,7 +69,7 @@ def telemetry_turned_on() -> bool:
     return telemetry if telemetry is not None else False
 
 
-def _get_anonymized_log_params(params: Dict[str, Any], steps_manager: StepsManagerType=None) -> Dict[str, Any]:
+def _get_anonymized_log_params(params: Dict[str, Any], steps_manager: Optional[StepsManagerType]=None) -> Dict[str, Any]:
     """
     Private params are where we _make sure_ that no private
     user data leaves the user's machine. We replace any potentially
@@ -89,7 +89,7 @@ def _get_anonymized_log_params(params: Dict[str, Any], steps_manager: StepsManag
     return private_params
 
 
-def _get_execution_data_log_params(steps_manager: StepsManagerType=None) -> Dict[str, Any]:
+def _get_execution_data_log_params(steps_manager: Optional[StepsManagerType]=None) -> Dict[str, Any]:
     """
     Get the execution params as well, again making sure
     to remove any private data.
@@ -108,7 +108,7 @@ def _get_execution_data_log_params(steps_manager: StepsManagerType=None) -> Dict
 
     return execution_data_params
 
-def _get_wsc_log_params(steps_manager: StepsManagerType=None) -> Dict[str, Any]:
+def _get_wsc_log_params(steps_manager: Optional[StepsManagerType]=None) -> Dict[str, Any]:
     """
     Get data from the widget state container that is useful for any
     log event. Note that none of this is private data.
@@ -129,7 +129,7 @@ def _get_wsc_log_params(steps_manager: StepsManagerType=None) -> Dict[str, Any]:
     else:
         return {}
 
-def _get_error_log_params(failed: bool=False, mito_error: MitoError=None)-> Dict[str, Any]:
+def _get_error_log_params(failed: bool=False, mito_error: Optional[MitoError]=None)-> Dict[str, Any]:
     """
     Get relevant logging data from any recently thrown error
     """
@@ -147,7 +147,7 @@ def _get_error_log_params(failed: bool=False, mito_error: MitoError=None)-> Dict
     else:
         return {}
 
-def _get_processing_time_log_params(steps_manager: StepsManagerType=None, start_time: float=None)-> Dict[str, Any]:
+def _get_processing_time_log_params(steps_manager: Optional[StepsManagerType]=None, start_time: Optional[float]=None)-> Dict[str, Any]:
     """
     Get data relevant for measuring performance impact
     """
@@ -191,12 +191,21 @@ try:
     from notebook import __version__ as notebook_version
 except:
     notebook_version = 'No notebook'
+try:
+    from pandas import __version__ as pandas_version
+except:
+    pandas_version = 'no pandas'
+try:
+    from ipywidgets import __version__ as ipywidgets_version
+except:
+    ipywidgets_version = 'no pandas'
+
 
 location = None
 
-def _get_enviornment_params() -> Dict[str, Any]:
+def _get_environment_params() -> Dict[str, Any]:
     """
-    Get data relevant for tracking the enviornment, so we can 
+    Get data relevant for tracking the environment, so we can 
     ensure Mitosheet compatibility with any system
     """
     global location
@@ -204,8 +213,10 @@ def _get_enviornment_params() -> Dict[str, Any]:
         location = get_location()
     
     # Add the python properties to every log event we can
-    enviornment_params = {
+    environment_params = {
         'version_python': sys.version_info,
+        'version_pandas': pandas_version,
+        'version_ipywidgets': ipywidgets_version,
         'version_jupyterlab': jupyterlab_version,
         'version_notebook': notebook_version,
         'version_mito': __version__,
@@ -214,7 +225,7 @@ def _get_enviornment_params() -> Dict[str, Any]:
         'is_docker': is_docker()
     }
 
-    return enviornment_params
+    return environment_params
 
 experiment = None
 def _get_experiment_params() -> Dict[str, Any]:
@@ -240,7 +251,7 @@ def _get_experiment_params() -> Dict[str, Any]:
 
     return experiment_params
 
-def log_event_processed(event: Dict[str, Any], steps_manager: StepsManagerType, failed: bool=False, mito_error: MitoError=None, start_time: float=None) -> None:
+def log_event_processed(event: Dict[str, Any], steps_manager: StepsManagerType, failed: bool=False, mito_error: Optional[MitoError]=None, start_time: Optional[float]=None) -> None:
     """
     Helper function for logging when an event is processed by the backend,
     including an edit event, an api call, or an update event. 
@@ -313,6 +324,8 @@ def identify() -> None:
         # NOTE: we do not log anything when tests are running
         analytics.identify(static_user_id, {
             'version_python': sys.version_info,
+            'version_pandas': pandas_version,
+            'version_ipywidgets': ipywidgets_version,
             'version_sys': sys.version,
             'version_mito': __version__,
             'package_name': package_name, 
@@ -327,7 +340,7 @@ def identify() -> None:
         })
 
 
-def log(log_event: str, params: Dict[str, Any]=None, steps_manager: StepsManagerType=None, failed: bool=False, mito_error: MitoError=None, start_time: float=None) -> None:
+def log(log_event: str, params: Optional[Dict[str, Any]]=None, steps_manager: Optional[StepsManagerType]=None, failed: bool=False, mito_error: Optional[MitoError]=None, start_time: Optional[float]=None) -> None:
     """
     This function is the entry point for all logging. It collects
     all relevant parameters, exeuction data, and more info while
@@ -357,8 +370,8 @@ def log(log_event: str, params: Dict[str, Any]=None, steps_manager: StepsManager
     # Then, get the logs for the processing time of the operation
     final_params = {**final_params, **_get_processing_time_log_params(steps_manager=steps_manager, start_time=start_time)}
 
-    # Then, get the params for the enviornment 
-    final_params = {**final_params, **_get_enviornment_params()}
+    # Then, get the params for the environment 
+    final_params = {**final_params, **_get_environment_params()}
 
     # Then, get the params for the all experiments
     final_params = {**final_params, **_get_experiment_params()}
