@@ -12,7 +12,7 @@ import pytest
 import pandas as pd
 import sys
 
-from mitosheet.utils import is_prev_version
+from mitosheet.utils import is_prev_version, is_snowflake_connector_python_installed, is_snowflake_credentials_available
 
 pandas_pre_1_only = pytest.mark.skipif(
     pd.__version__.startswith('1.'), 
@@ -54,3 +54,11 @@ python_post_3_6_only = pytest.mark.skipif(
     reason="requires 3.7 or greater"
 )
 
+requires_snowflake_dependencies_and_credentials = pytest.mark.skipif(
+    not is_snowflake_connector_python_installed() or not is_snowflake_credentials_available(),
+    reason='requires snowflake_connecto_python package and snowflake credentials'
+)
+
+
+
+
