@@ -1,6 +1,3 @@
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GNU Affero General Public License v3.0 License.
-
 import subprocess
 import os
 
@@ -9,7 +6,7 @@ import pytest
 
 from mitosheet.mito_backend import get_mito_frontend_code
 from mitosheet.steps_manager import StepsManager
-from mitosheet.tests.test_utils import create_mito_wrapper
+from mitosheet.tests.test_utils import create_mito_wrapper_dfs
 
 
 # See here: https://www.tutorialspoint.com/json_simple/json_simple_escape_characters.htm
@@ -33,7 +30,7 @@ STRINGS_TO_TEST = [
 
 def write_test_code(file: str, string: str) -> None:
     df = pd.DataFrame({'A': [string]})
-    mito = create_mito_wrapper(df)
+    mito = create_mito_wrapper_dfs(df)
     code = get_mito_frontend_code('a', 'a', 'a', mito.mito_backend)
     with open(file, 'w+') as f:
         f.write(code)
