@@ -31,7 +31,9 @@ from mitosheet.step_performers import (
     ExcelImportStepPerformer,
     DropDuplicatesStepPerformer,
     GraphStepPerformer,
-    ConcatStepPerformer
+    ConcatStepPerformer,
+    ExcelRangeImportStepPerformer,
+    SnowflakeImportStepPerformer
 )
 from mitosheet.step_performers.import_steps.dataframe_import import DataframeImportStepPerformer
 from mitosheet.step_performers.delete_row import DeleteRowStepPerformer
@@ -272,4 +274,16 @@ def test_params_static():
         'dataframe_import'
     )
 
-    assert len(STEP_PERFORMERS) == 32
\ No newline at end of file
+    check_step(
+        ExcelRangeImportStepPerformer,
+        1,
+        'excel_range_import'
+    )
+
+    check_step(
+        SnowflakeImportStepPerformer,
+        1,
+        'snowflake_import'
+    )
+
+    assert len(STEP_PERFORMERS) == 34
\ No newline at end of file
