@@ -5,6 +5,7 @@
 # Distributed under the terms of the GPL License.
 import pandas as pd
 import pytest
+from mitosheet.enterprise.mito_config import MitoConfig
 
 from mitosheet.utils import get_new_id
 from mitosheet.errors import MitoError
@@ -17,12 +18,15 @@ def test_create_steps_manager():
     df1 = pd.DataFrame(data={'A': [123]})
     df2 = pd.DataFrame(data={'A': [123]})
 
-    steps_manager = StepsManager([df1, df2])
+    mito_config = MitoConfig()
+
+    steps_manager = StepsManager([df1, df2], mito_config.get_mito_config())
     assert steps_manager.curr_step_idx == 0
     assert steps_manager.curr_step.step_type == 'initialize'
     assert steps_manager.curr_step.column_spreadsheet_code == [{'A': ''}, {'A': ''}]
     assert steps_manager.curr_step.dfs[0].equals(df1)
     assert steps_manager.curr_step.dfs[1].equals(df2)
+    assert steps_manager.mito_config == mito_config.get_mito_config()
 
 # We assume only column A exists
 CELL_EDIT_ERRORS = [
@@ -42,7 +46,7 @@ def test_steps_manager_cell_edit_errors(formula,error_type):
     mito = create_mito_wrapper([123])
     mito.add_column(0, 'B')
     with pytest.raises(MitoError) as e_info:
-        mito.mito_widget.steps_manager.handle_edit_event({
+        mito.mito_backend.steps_manager.handle_edit_event({
             'event': 'edit_event',
             'id': get_new_id(),
             'type': 'set_column_formula_edit',
@@ -61,11 +65,11 @@ def test_overwrites_step_valid():
     mito = create_mito_wrapper([1, 2, 3])
     mito.add_column(0, 'B')
 
-    mito.mito_widget.receive_message(mito.mito_widget, {
+    mito.mito_backend.receive_message({
         'event': 'edit_event',
         'id': get_new_id(),
         'type': 'add_column_edit',
-        'step_id': mito.mito_widget.steps_manager.curr_step.step_id,
+        'step_id': mito.mito_backend.steps_manager.curr_step.step_id,
         'params': {
             'sheet_index': 0,
             'column_header': 'C',
@@ -73,7 +77,7 @@ def test_overwrites_step_valid():
         }
     })
 
-    assert len(mito.steps) == 3
+    assert len(mito.steps_including_skipped) == 3
     assert mito.dfs[0].equals(pd.DataFrame(data={'A': [1, 2, 3], 'C': [0, 0, 0]}))
 
 
@@ -81,11 +85,11 @@ def test_failed_overwrite_rolls_back_to_previous_state():
     mito = create_mito_wrapper([1, 2, 3])
     mito.add_column(0, 'B')
 
-    mito.mito_widget.receive_message(mito.mito_widget, {
+    mito.mito_backend.receive_message({
         'event': 'edit_event',
         'id': get_new_id(),
         'type': 'add_column_edit',
-        'step_id': mito.mito_widget.steps_manager.curr_step.step_id,
+        'step_id': mito.mito_backend.steps_manager.curr_step.step_id,
         'params': {
             'sheet_index': 1,
             'column_header': 'C',
@@ -93,7 +97,7 @@ def test_failed_overwrite_rolls_back_to_previous_state():
         }
     })
 
-    assert len(mito.steps) == 2
+    assert len(mito.steps_including_skipped) == 2
     assert mito.dfs[0].equals(pd.DataFrame(data={'A': [1, 2, 3], 'B': [0, 0, 0]}))
 
 
