@@ -11,6 +11,7 @@ from random import randint
 import re
 import uuid
 from typing import Any, Dict, List, Optional, Set, Tuple
+import os
 
 import numpy as np
 import pandas as pd
@@ -54,7 +55,7 @@ def get_valid_dataframe_name(existing_df_names: List[str], original_dataframe_na
 
     # A valid variable name cannot be empty, or start with a number
     if len(dataframe_name) == 0 or dataframe_name[0].isdecimal():
-        return 'df_' + dataframe_name
+        return get_first_unused_dataframe_name(existing_df_names, 'df_' + dataframe_name)
 
     return get_first_unused_dataframe_name(existing_df_names, dataframe_name)
 
@@ -342,4 +343,20 @@ def is_prev_version(curr_version: str, benchmark_version: str) -> bool:
         if int(old_version_part) < int(benchmark_version_part):
             return True
 
-    return False
\ No newline at end of file
+    return False
+
+def is_snowflake_connector_python_installed() -> bool:
+    try:
+        import snowflake.connector
+        return True
+    except ImportError:
+        return False
+
+
+def is_snowflake_credentials_available() -> bool:
+    PYTEST_SNOWFLAKE_USERNAME = os.getenv('PYTEST_SNOWFLAKE_USERNAME')
+    PYTEST_SNOWFLAKE_PASSWORD = os.getenv('PYTEST_SNOWFLAKE_PASSWORD')
+    PYTEST_SNOWFLAKE_ACCOUNT = os.getenv('PYTEST_SNOWFLAKE_ACCOUNT')
+
+    return PYTEST_SNOWFLAKE_USERNAME is not None and PYTEST_SNOWFLAKE_PASSWORD is not None and PYTEST_SNOWFLAKE_ACCOUNT is not None and \
+        PYTEST_SNOWFLAKE_USERNAME != 'None' and PYTEST_SNOWFLAKE_PASSWORD != 'None' and PYTEST_SNOWFLAKE_ACCOUNT != 'None'
\ No newline at end of file
